
**Name** - Arunain
**Roll no.** - 102016011


## Installation


```bash
pip install Topsis-Arunain-102016011
```

## Usage

Following query on terminal will provide you the topsis analysis for input csv file.

```
Topsis-Arunain-102016011 -n "dataset-name.csv" -w "w1,w2,w3,w4,..." -i "i1,i2,i3,i4,..."

```

w1,w2,w3,w4 represent weights, and i1,i2,i3,i4 represent impacts where 1 is used for maximize and 0 for minimize. 
Size of w and i is equal to number of features. 

Note that the first row and first column of dataset is dropped

Rank 1 signifies best decision



MIT